<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       www.teowin.nl
 * @since      1.0.0
 *
 * @package    Pw
 * @subpackage Pw/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Pw
 * @subpackage Pw/admin
 * @author     Teowin <plugins@teowin.nl>
 */
class Pw_Admin {

    var $license;

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

        $this->licence = new Powerall_dropshipment_Licence();

//        if ( ! $this->licence->licence_key_verify() ) {
//           add_action( 'admin_notices', array( $this, 'admin_no_key_notices' ) );
//           add_action( 'network_admin_notices', array( $this, 'admin_no_key_notices' ) );
//        }

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Pw_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Pw_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/pw-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Pw_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Pw_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/pw-admin.js', array( 'jquery' ), time(), true );
		wp_register_style( 'select2css', '//cdnjs.cloudflare.com/ajax/libs/select2/3.4.8/select2.css', false, '1.0', 'all' );
		wp_register_script( 'select2', '//cdnjs.cloudflare.com/ajax/libs/select2/3.4.8/select2.js', array( 'jquery' ), '1.0', true );
		wp_enqueue_style( 'select2css' );
		wp_enqueue_script( 'select2' );
	}

	/**
	 * Registers a setting.
	 */
	public function register_powerall_settings() {
		register_setting( 'powerall-settings', 'powerall_login' );
		register_setting( 'powerall-settings', 'powerall_password'  );
		register_setting( 'powerall-settings', 'powerall_hash');
		register_setting( 'powerall-settings',  'powerall_taxes');
		register_setting( 'powerall-settings',  'powerall_shipments');
		register_setting( 'powerall-settings',  'powerall_payments');
	}

    function admin_no_key_notices() {
        if ( ! current_user_can( 'manage_options' ) ) {
            return;
        }

        $screen = get_current_screen();

        if ( is_multisite() ) {
            if ( isset( $screen->id ) && $screen->id == 'settings_page_woo-ms-options-network' ) {
                return;
            }
            ?>
            <div class="updated error">
            <p><?php _e( "Teowin Powerall Dropshipment is inactive, please enter your", 'wooslt' ) ?> <a
                        href="<?php echo network_admin_url() ?>options-general.php?page=<?php echo POWERALL_DS_PRODUCT_ID ?>"><?php _e( "License Key", 'wooslt' ) ?></a>
                to get updates</p></div><?php
        } else {
            if ( isset( $screen->id ) && $screen->id == POWERALL_DS_PRODUCT_ID ) {
                return;
            }

            ?>
            <div class="updated error">
            <p><?php _e( "Teowin Powerall Dropshipment is inactive, please enter your", 'wooslt' ) ?> <a
                        href="admin.php?page=<?php echo POWERALL_DS_PRODUCT_ID ?>"><?php _e( "License Key", 'wooslt' ) ?></a>
                to get updates</p></div><?php
        }
    }

	public function powerall_woocommerce_product_class( $classname, $product_type ) {

		if ( $product_type == 'pw_product' ) {
			$classname = 'WC_Product_Powerall';
		}

		return $classname;
	}

	public function add_powerall_product_type( $types ){
		$types[ 'pw_product' ] = 'Powerall';
	//	unset( $product_types['grouped'] );
		unset( $types['external'] );
		//unset( $product_types['variable'] );

		return $types;
	}

	public function powerall_show_tabs($tabs) {

		$tabs ['pw_product'] = array (
			'label' => __ ( 'PowerAll connected', 'twpowerall' ),
			'target' => 'powerall_product_data',
			'class' => array (
			//	'show_if_pw_product',
			//	'hide_if_simple',
			//	'hide_if_grouped',
			//	'hide_if_external',
			//	'hide_if_variable'
			), 
			'priority' => 10,
		);

		return $tabs;
	}


	/**
	 * Hide Attributes data panel.
	 */
	public function powerall_hide_attributes_data_panel($tabs) {

		// Other default values for 'attribute' are; general, inventory, shipping, linked_product, variations, advanced
	$tabs['general_tab']['class'][] = 'show_if_pw_product';
    $tabs['inventory']['class'][] = 'show_if_pw_product';
	$tabs['shipping']['class'][] = 'show_if_pw_product';
//	$tabs['variations']['class'][] = 'hide_if_pw_product';
	$tabs['atrributes']['class'][] = 'hide_if_pw_product';
	$tabs['pw_product']['class'][] = 'show_if_simple';

		return $tabs;
	}

	public function powerall_product_type_options($options){
		$options['downloadable']['wrapper_class'] = 'show_if_simple hide_if_pw_product';
		$options['virtual']['wrapper_class'] = 'show_if_simple hide_if_pw_product';
		return $options;
	}

	/**
	 * Contents of the powerall options product tab.
	 */
	public function powerall_options_product_tab_content() {
		global $post;

		$thepowerallID = 0;

    	$type = 'pw_product';

		$wc_product = wc_get_product($post->ID);
		if ($wc_product->is_type('pw_product')) {
			    $type = 'pw_product';

			   $thepowerallID = get_post_meta($post->ID, '_powerallId', true);
		}
		?>

		<div id='powerall_product_data' class='panel woocommerce_options_panel'>
			<div class='options_group'>
				<?php
				if (!isset($thepowerallID) | ($thepowerallID == '')) {
					echo '  <p id="Powerall_Button" class="form-field"> ';
					echo '     <span><label for="powerallIDInput">Get from Powerall API</label>';
					echo '      <span> ';
					echo '          <input type="text" id="powerallIDinput" class="powerallIDinput" />';
					echo '          <button id="get_powerall_product_button" class="get_powerall_product_button button-primary button-large" class="button" role="button" style="margin-left: 10px;">Load</button> ';
					echo '      </span>';
					echo '      </span>';
					echo '  </p>';
				}
				// else
				//{

				woocommerce_wp_text_input( array(
					'id'			=> '_productcode',
					'label'			=> __( 'ProductCode', 'twpowerall' ),
					'desc_tip'		=> 'false',
					'description'	=> __( 'The PowerAll Product ID (readonly)', 'twpowerall' ),
					'type' 			=> 'text',
                    'custom_attributes' => array('readonly' => 'readonly'),
				) );

				woocommerce_wp_text_input( array(
					'id'			=> '_invoicetext',
					'label'			=> __( 'Invoice text', 'twpowerall' ),
					'desc_tip'		=> 'true',
					'description'	=> __( 'Invoice text (readonly)', 'twpowerall' ),
					'type' 			=> 'text',
                    'name'          => 'invoicetext',
                    'style'         => 'readonly',
                    'custom_attributes' => array('readonly' => 'readonly'),

				) );

				// Number Field
				woocommerce_wp_text_input(
					array(
						'id'          => '_regular_price',
						'label'       => __( 'Sales Price', 'twpowerall' ),
						'desc_tip'    => 'true',
						'description' => __( 'Powerall sale price.', 'twpowerall' ),
                        'custom_attributes' => array('readonly' => 'readonly'),
					)
				);

				woocommerce_wp_text_input( array(
					'id'			=> '_promotionalprice',
					'label'			=> __( 'Promotional Price', 'twpowerall' ),
					'desc_tip'		=> 'false',
					'description'	=> __( 'Promotional Price', 'twpowerall' ),
					'type' 			=> 'text',
                    'custom_attributes' => array('readonly' => 'readonly'),
				) );

				//  }


				?></div>

		</div>
		<script>

            //  alert('script werkt');
            jQuery("#get_powerall_product_button").click(function(button){
                button.preventDefault();
                //  $("#save-post").click();
                var powerallpc = jQuery(".powerallIDinput").val();
                jQuery.ajax({
                    method: "POST",
                    url: ajaxurl,
                    async: false,
                    data: { 'action': 'get_single_product',
                            'productcode' : powerallpc,
                            'postid' : <?php echo $post->ID; ?>
                    }
                })
                    .done(function( data ) {
                        if ( true === data.success ) {

                            window.location.href = window.location.href;
                        } else {

                            // Otherwise, handle the errors or the messages that were provided by the server, here.
                            error_codes    = data.data[0].code;
                            error_messages = data.data[0].message;
                            alert('Error getting game data: Errorcode: ' + error_codes + 'message: ' + error_messages);

                        }

                    })
                    .fail(function( data ) {
                        console.log('Failed AJAX Call -> Return Data: ' + data );
                        alert('Getting data has failed. Is your Powerall ID correct?' + data);
                    })
            });


		</script>
		<?php

	}

	/**
	 * Register the administration menu for this plugin into the WordPress Dashboard menu.
	 *
	 * @since    1.0.0
	 */

	public function add_plugin_admin_menu() {

		/*
		 * Add a settings page for this plugin to the Settings menu.
		 *
		 * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
		 *
		 *        Administration Menus: http://codex.wordpress.org/Administration_Menus
		 *
		 */
		add_options_page( 'WooCommerce-Powerall Plugin Settings', 'Powerall koppeling', 'manage_options', $this->plugin_name, array($this, 'display_plugin_setup_page'));
	}

	/**
	 * Add settings action link to the plugins page.
	 *
	 * @since    1.0.0
	 */

	public function add_action_links( $links ) {
		/*
		*  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
		*/
		$settings_link = array(
			'<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_name ) . '">' . __('Settings', $this->plugin_name) . '</a>',
		);
		return array_merge(  $settings_link, $links );

	}

	/**
	 * Render the settings page for this plugin.
	 *
	 * @since    1.0.0
	 */

	public function display_plugin_setup_page() {

	    include( 'partials/pw-admin-display.php' );
	}

	public function powerall_script_enqueuer()
	{
		/**
		/wp-admin/edit.php?post_type=post
		/wp-admin/edit.php?post_type=page
		/wp-admin/edit.php?post_type=cpt  == gallery in this example
		 */

		if (isset($_GET['post_type']) && ($_GET['post_type'] !== 'product'))
			return;

		global $post;
		if ($post->post_type == 'product') {
			$wc_product = wc_get_product( $post->ID );

			if ( isset( $wc_product ) ) {

				if ( $wc_product->is_type( 'pw_product' ) ) {

					?>
					<script type="text/javascript">

                        jQuery(document).ready(function ($) {
                            $('div#woocommerce-fields').hide();

                            $('span:contains("Slug")').each(function (i) {
                                $(this).parent().remove();
                            });
                            $('span:contains("Password")').each(function (i) {
                                $(this).parent().parent().remove();
                            });
                            $('span:contains("Date")').each(function (i) {
                                $(this).parent().remove();
                            });
                            $('.inline-edit-date').each(function (i) {
                                $(this).remove();
                            });
                        });

                     //   jQuery('.description_tab, .description_pane').removeClass('active');
                      //  jQuery('#powerall_product_data').addClass('active');
					</script>
					<?php
				}
			}
		}
	}

 /* STRIP_comment
 */
	public function powerall_display_user_profile_fields($user){?>
    <h3><?php _e("Powerall Exchange Settings", "blank"); ?></h3>
    <?php
       if (esc_attr( get_the_author_meta( 'isActive', $user->ID )) == false){

           $divstyle = 'background-color: orange; width=70%; border: 1px solid black; font-size: 12px; align:"center"';
           $message = __( 'Notice! Customer is not activated in Powerall.', 'twpw' );

           printf( '<div style="%1$s"><p style="text-align: center; font-size: 1.3em;">%2$s</p></div>', esc_attr( $divstyle ), esc_html( $message ) );

       }
    ?>
    <table class="form-table">
        <tr>
            <th><label for="powerall_id"><?php _e("Powerall ID"); ?></label></th>
            <td>
                <input type="text" name="powerall_id" id="powerall_id" value="<?php echo esc_attr( get_the_author_meta( 'powerall_id', $user->ID ) ); ?>" class="regular-text" /><br />
                <span class="description"><?php _e("Powerall ID for the customer."); ?></span>
            </td>
        </tr>
        <tr>
            <th><label for="powerall_relationcode"><?php _e("Powerall RelationCode"); ?></label></th>
            <td>
                <input type="text" name="powerall_relationcode" id="powerall_relationcode" value="<?php echo esc_attr( get_the_author_meta( 'powerall_relationcode', $user->ID ) ); ?>" class="regular-text" /><br />
                <span class="description"><?php _e("Powerall relationcode."); ?></span>
            </td>
        </tr>
        <tr>
            <th><label for="discount_group"><?php _e("Discount Group"); ?></label></th>
            <td>
                <input type="text" name="discount_group" id="discount_group" value="<?php echo esc_attr( get_the_author_meta( 'discount_group', $user->ID ) ); ?>" class="regular-text" /><br />
                <span class="description"><?php _e("Powerall discount group (as set in PowerAll, this is a number)."); ?></span>
            </td>
        </tr>
        <tr>
            <th><label for="paycondition"><?php _e("Payment Condition"); ?></label></th>
            <td>
                <input type="text" name="paycondition" id="paycondition" value="<?php echo esc_attr( get_the_author_meta( 'paycondition', $user->ID ) ); ?>" class="regular-text" /><br />
                <span class="description"><?php _e("Payment condition (a single number)."); ?></span>
            </td>
        </tr>
        <tr>
            <th><label for="acceptorders"><?php _e("acceptorders"); ?></label></th>
            <td>
                <input type="checkbox" name="acceptorders" id="acceptorders" value="yes" <?php if (esc_attr( get_the_author_meta( "acceptorders", $user->ID )) == "yes") echo "checked"; ?> />
                <span class="description"><?php _e("Check if the customer can place orders."); ?></span>
            </td>
        </tr>
    </table>
    <?php }

    function powerall_save_user_fields( $user_id ) {

        if ( !current_user_can( 'edit_user', $user_id ) ) {
            return false;
        }

        update_user_meta( $user_id, 'powerall_id', $_POST['powerall_id'] );
        update_user_meta( $user_id, 'powerall_relationcode', $_POST['powerall_relationcode'] );
        update_user_meta( $user_id, 'discount_group', $_POST['discount_group'] );
        update_user_meta( $user_id, 'paycondition', $_POST['paycondition'] );
        update_user_meta( $user_id, 'acceptorders', $_POST['acceptorders'] );


        // Update Powerall API.
        $pwDropShipment = PwDropShipment::get_instance();
        $pwDropShipment->update_customer();

    }

	//Product Cat Create page
	function wh_taxonomy_add_new_meta_field() {
		?>
        <div class="form-field">
            <label for="pw_meta_frompw"><?php _e('Powerall Category', 'wh'); ?></label>
            <input type="checkbox" name="pw_meta_frompw" id="pw_meta_frompw"/>
            <p class="description"><?php _e('Check if the category is a Powerall category (is overwritten by the API)', 'wh'); ?></p>
        </div>
<!--        <div class="form-field">
            <label for="pw_meta_discountgroup"><?php /*_e('DiscountGroup', 'wh'); */?></label>
            <input type="text" name="pw_meta_discountgroup" id="pw_meta_discountgroup" readonly>
            <p class="description"><?php /*_e('Discountgroup in Powerall -> should be changed in Powerall', 'wh'); */?></p>
        </div>
        <div class="form-field">
            <label for="pw_meta_discount"><?php /*_e('Discount', 'wh'); */?></label>
            <input type="text" name="pw_meta_discount" id="pw_meta_discount" readonly>
            <p class="description"><?php /*_e('Discount in Powerall -> should be changed in Powerall', 'wh'); */?></p>
        </div>

-->

		<?php
	}

//Product Cat Edit page
	function wh_taxonomy_edit_meta_field($term) {

		//getting term ID
		$term_id = $term->term_id;

		// retrieve the existing value(s) for this meta field.
		$pw_meta_discount = get_term_meta($term_id, 'pw_meta_discount', true);
		$pw_meta_discountgroup = get_term_meta($term_id, 'pw_meta_discountgroup', true);
		$pw_meta_frompw = get_term_meta($term_id, 'pw_meta_frompw', true);
		?>
        <tr class="form-field">
            <th scope="row" valign="top"><label for="pw_meta_frompw"><?php _e('Powerall Category', 'twpw'); ?></label></th>
            <td>
                <input type="checkbox" name="pw_meta_frompw" id="pw_meta_frompw" <?php if (esc_attr( $pw_meta_frompw ) == "on") echo "checked"; ?> />
                <p class="description"><?php _e('Check if the category is a Powerall category', 'wh'); ?></p>
            </td>
        </tr>
        <tr class="form-field">
            <th scope="row" valign="top"><label for="pw_meta_discountgroup"><?php _e('DiscountGroup', 'twpw'); ?></label></th>
            <td>
                <input type="text" name="pw_meta_discountgroup" id="pw_meta_discountgroup" readonly  value="<?php echo esc_attr($pw_meta_discountgroup ? esc_attr($pw_meta_discountgroup) : ''); ?> ">
                <p class="description"><?php _e('Discountgroup in Powerall -> should be changed in Powerall', 'wh'); ?></p>
            </td>
        </tr>
        <tr class="form-field">
            <th scope="row" valign="top"><label for="pw_meta_discount"><?php _e('Discount', 'twpw'); ?></label></th>
            <td>
                <input type="text" name="pw_meta_discount" id="pw_meta_discount" readonly  value="<?php echo esc_attr($pw_meta_discount ? esc_attr($pw_meta_discount) : ''); ?> ">
                <p class="description"><?php _e('Discount in Powerall -> should be changed in Powerall', 'wh'); ?></p>
            </td>
        </tr>
		<?php
	}

	// Save extra taxonomy fields callback function.
	function wh_save_taxonomy_custom_meta($term_id) {
		$pw_meta_discount = filter_input(INPUT_POST, 'pw_meta_discount');
		$pw_meta_discountgroup = filter_input(INPUT_POST, 'pw_meta_discountgroup');
		$pw_meta_frompw = filter_input(INPUT_POST, 'pw_meta_frompw');

		update_term_meta($term_id, 'pw_meta_discount', $pw_meta_discount);
		update_term_meta($term_id, 'pw_meta_discountgroup', $pw_meta_discountgroup);
		update_term_meta($term_id, 'pw_meta_frompw', $pw_meta_frompw);
	}


   
}




	

