<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


if ( ! class_exists( 'WC_Settings_MyPlugin' ) ) :


	function my_plugin_add_settings() {

		/**
		 * Settings class
		 *
		 * @since 1.0.0
		 */
		class WC_Settings_MyPlugin extends WC_Settings_Page {


			/**
			 * Setup settings class
			 *
			 * @since  1.0
			 */
			public function __construct() {

				$this->id    = 'twpw';
				$this->label = __( 'Powerall', 'twpw' );

				add_filter( 'woocommerce_settings_tabs_array',        array( $this, 'add_settings_page' ), 20 );
				add_action( 'woocommerce_settings_' . $this->id,      array( $this, 'output' ) );
				add_action( 'woocommerce_settings_save_' . $this->id, array( $this, 'save' ) );
				add_action( 'woocommerce_sections_' . $this->id,      array( $this, 'output_sections' ) );

			}


			/**
			 * Get sections
			 *
			 * @return array
			 */
			public function get_sections() {

				$sections = array(
					'Orders' => __( 'Naar Powerall', 'twpw' ),
					'second' => __( 'Synchronisatie', 'twpw' )
				);

				return apply_filters( 'woocommerce_get_sections_' . $this->id, $sections );
			}


			/**
			 * Get settings array
			 *
			 * @since 1.0.0
			 * @param string $current_section Optional. Defaults to empty string.
			 * @return array Array of settings
			 */
			public function get_settings( $current_section = '' ) {

				if ( 'second' == $current_section ) {

					/**
					 * Filter Plugin Section 2 Settings
					 *
					 * @since 1.0.0
					 * @param array $settings Array of the plugin settings
					 */
					$settings = apply_filters( 'myplugin_section2_settings', array(

						array(
							'name' => __( 'Synchronisatie/Overige instellingen', 'twpw' ),
							'type' => 'title',
							'desc' => 'Hier staan instellingen die de werking van het synchroniseren beïnvloeden',
							'id'   => 'twpw_general',
						),

                        array(
                            'type'     => 'checkbox',
                            'id'       => 'gebruikwebshoptekst',
                            'name'     => __( 'Webshoptext tekst gebruiken?', 'twpw' ),
                            'desc'     => __( 'Aanzetten gebruikt de platte tekst uit Powerall, de klant moet dan zelf HTML invoeren in Powerall. ', 'twpw' ),
                            'default'  => 'no',
                        ),
                        array(
                            'type'     => 'checkbox',
                            'id'       => 'altijdoverschrijven',
                            'name'     => __( 'Productteksten altijd overschrijven?', 'twpw' ),
                            'desc'     => __( 'Ja: bij elke update uit Powerall overschrijft de productekst, Nee: de productteksten in de webshop zijn leidend', 'twpw' ),
                            'default'  => 'no',
                        ),
                        array(
                            'type'     => 'checkbox',
                            'id'       => 'gebruikproductgroepen',
                            'name'     => __( 'Powerall productgroepen gebruiken?', 'twpw' ),
                            'desc'     => __( 'Aanzetten gebruikt de categorieen uit Powerall en maakt die waar nodig zelf bij. ', 'twpw' ),
                            'default'  => 'no',
                        ),


						array(
							'type' => 'sectionend',
							'id'   => 'myplugin_group2_options'
						),

					) );

				} else {

					/**
					 * Filter Plugin Section 1 Settings
					 *
					 * @since 1.0.0
					 * @param array $settings Array of the plugin settings
					 */
					$settings = apply_filters( 'myplugin_section1_settings', array(

						array(
							'name' => __( 'Orders', 'my-textdomain' ),
							'type' => 'title',
							'desc' => 'Opties voor versturen van orders naar de Powerall API. ',
							'id'   => 'myplugin_important_options',
						),
                        array(
                            'type' => 'text',
                            'name'     => __( 'debiteurnummer voor contantfactuur', 'twpw' ),
                            'desc_tip' => true,
                            'id'	=> 'contantfactdebiteur'

                        ),
						array(
							'type' => 'sectionend',
							'id'   => 'twpw_ordersection_end'
						),

					) );

				}

				/**
				 * Filter MyPlugin Settings
				 *
				 * @since 1.0.0
				 * @param array $settings Array of the plugin settings
				 */
				return apply_filters( 'woocommerce_get_settings_' . $this->id, $settings, $current_section );

			}


			/**
			 * Output the settings
			 *
			 * @since 1.0
			 */
			public function output() {

				global $current_section;

				$settings = $this->get_settings( $current_section );
				WC_Admin_Settings::output_fields( $settings );
			}


			/**
			 * Save settings
			 *
			 * @since 1.0
			 */
			public function save() {

				global $current_section;

				$settings = $this->get_settings( $current_section );
				WC_Admin_Settings::save_fields( $settings );
			}

		}

		return new WC_Settings_MyPlugin();

	}
	add_filter( 'woocommerce_get_settings_pages', 'my_plugin_add_settings', 15 );

endif;