<?php

/*
 *  T
 */

/*
 * This action hook registers our PHP class as a WooCommerce payment gateway
 */
add_filter( 'woocommerce_payment_gateways', 'add_powerall_gateway_class' );
function add_powerall_gateway_class( $gateways ) {
    if ( class_exists( 'WooCommerce' ) ) {
        $gateways[] = 'WC_Powerall_Gateway'; // your class name is here
    }
	return $gateways;
}

/*
 * The class itself, please note that it is inside plugins_loaded action hook
 */
if ( class_exists( 'WooCommerce' ) ) {
    add_action('plugins_loaded', 'init_powerall_gateway_class');
}

function init_powerall_gateway_class() {

	class WC_Powerall_Gateway extends WC_Payment_Gateway {

		/**
		 * Class constructor, more about it in Step 3
		 */
		public function __construct() {
			$this->id = 'powerall'; // payment gateway plugin ID
			$this->icon = ''; // URL of the icon that will be displayed on checkout page near your gateway name
			$this->has_fields = true; // in case you need a custom credit card form
			$this->method_title = 'Powerall - Op rekening';
			$this->title='Powerall';

			$this->method_description = 'Klant koopt op rekening (krijgt een factuur uit Powerall)'; // will be displayed on the options page

			// gateways can support subscriptions, refunds, saved payment methods,
			// but in this tutorial we begin with simple payments
			$this->supports = array(
				'products', 'pw_products'
			);

			// Method with all the options fields
			$this->init_form_fields();

			// Load the settings.
			$this->init_settings();
			$this->title = $this->get_option( 'title' );
			$this->description = $this->get_option( 'description' );
			$this->enabled = $this->get_option( 'enabled' );
		//	$this->testmode = 'yes' === $this->get_option( 'testmode' );
		//	$this->private_key = $this->testmode ? $this->get_option( 'test_private_key' ) : $this->get_option( 'private_key' );
		//	$this->publishable_key = $this->testmode ? $this->get_option( 'test_publishable_key' ) : $this->get_option( 'publishable_key' );

			// This action hook saves the settings
			add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );

			// We need custom JavaScript to obtain a token
			add_action( 'wp_enqueue_scripts', array( $this, 'payment_scripts' ) );

			// You can also register a webhook here
			// add_action( 'woocommerce_api_{webhook name}', array( $this, 'webhook' ) );

		}

		/**
		 * Plugin options, we deal with it in Step 3 too
		 */
		public function init_form_fields(){

			$this->form_fields = array(
				'enabled' => array(
					'title'       => 'Enable/Disable',
					'label'       => 'Enable Factuur uit Powerall',
					'type'        => 'checkbox',
					'description' => '',
					'default'     => 'no'
				),
				'title' => array(
					'title'       => 'Title',
					'type'        => 'text',
					'description' => 'This controls the title which the user sees during checkout.',
					'default'     => 'Op rekening',
					'desc_tip'    => true,
				),
				'description' => array(
					'title'       => 'Description',
					'type'        => 'textarea',
					'description' => 'This controls the description which the user sees during checkout.',
					'default'     => 'Koop op rekening, u ontvangt een factuur bij uw bestelling.',
				),
				'instructions' => array(
					'title'       => 'Instructie',
					'type'        => 'textarea',
					'description' => 'This controls the description which the user sees during checkout.',
					'default'     => 'Koop op rekening, u ontvangt een factuur bij uw bestelling.',
				),
//				'testmode' => array(
//					'title'       => 'Test mode',
//					'label'       => 'Enable Test Mode',
//					'type'        => 'checkbox',
//					'description' => 'Place the payment gateway in test mode using test API keys.',
//					'default'     => 'yes',
//					'desc_tip'    => true,
//				),
//				'test_publishable_key' => array(
//					'title'       => 'Test Publishable Key',
//					'type'        => 'text'
//				),
//				'test_private_key' => array(
//					'title'       => 'Test Private Key',
//					'type'        => 'password',
//				),
//				'publishable_key' => array(
//					'title'       => 'Live Publishable Key',
//					'type'        => 'text'
//				),
//				'private_key' => array(
//					'title'       => 'Live Private Key',
//					'type'        => 'password'
//				)
			);

		}

		/**
		 * You will need it if you want your custom credit card form, Step 4 is about it
		 */
		public function payment_fields() {
		}

		/*
		 * Custom CSS and JS, in most cases required only when you decided to go with a custom credit card form
		 */
		public function payment_scripts() {
		}

		/*
 		 * Fields validation, more in Step 5
		 */
		public function validate_fields() {
		}

		/*
		 * We're processing the payments here, everything about it is in Step 5
		 */
		public function process_payment( $order_id ) {

			$order = wc_get_order( $order_id );

			// Mark as on-hold (we're awaiting the payment)
			$order->update_status( 'wc-powerall-ready', __( 'Klaar voor Powerall ', 'twpw' ) );
			$order->save();

			// Remove cart
			WC()->cart->empty_cart();

			// Return thankyou redirect
			return array(
				'result' 	=> 'success',
				'redirect'	=> $this->get_return_url( $order )
			);

		}

		/*
		 * In case you need a webhook, like PayPal IPN etc
		 */
		public function webhook() {

			//

		}
	}
}