<?php

defined( 'ABSPATH' ) || exit;

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       www.teowin.nl
 * @since      1.0.0
 *
 * @package    Pw
 * @subpackage Pw/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Pw
 * @subpackage Pw/includes
 * @author     Teowin <plugins@teowin.nl>
 */
class PwDropShipment {

	public $discountlist = array();

	private static $instance;

	/**
	 * Gets an instance of our plugin.
	 *
	 * @return PwDropShipment;
	 */
	public static function get_instance()
	{
		if (null === self::$instance) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Pw_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'PW_VERSION' ) ) {
			$this->version = PW_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'powerall';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		



		if (!session_id()) {
			session_start();
		}
		
		

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Pw_Loader. Orchestrates the hooks of the plugin.
	 * - Pw_i18n. Defines internationalization functionality.
	 * - Pw_Admin. Defines all hooks for the admin area.
	 * - Pw_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-pw-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-pw-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-pw-admin.php';
		
		/**
		 * The class responsible for the Woocommerce setting tab.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-pw-settings-tab.php';


		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-pw-public.php';

		/**
         * The powerall product type
         */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-pw-product.php';

		/**
		 * The powerall payment gateway
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-pw-gateway.php';

		$this->loader = new Pw_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Pw_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Pw_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

        if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

        } else {
      
            return;
        }

		$plugin_admin = new Pw_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

        // Add menu item
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'add_plugin_admin_menu' );

		// Add Settings link to the plugin
		$this->loader->add_filter( 'plugin_action_links_' . $this->plugin_name, $plugin_admin, 'add_action_links' );

		$this->loader->add_filter( 'woocommerce_product_class', $plugin_admin, 'powerall_woocommerce_product_class', 10, 2 );

		$this->loader->add_filter( 'product_type_selector', $plugin_admin, 'add_powerall_product_type');

		$this->loader->add_action( 'product_type_options', $plugin_admin, 'powerall_product_type_options' );

		$this->loader->add_action('wp_ajax_get_single_product', $this, 'get_one_product');
		$this->loader->add_action('wp_ajax_settings_sync_users', $this, 'get_all_customers_from_API');
		$this->loader->add_action('wp_ajax_create_hash', $this, 'generate_API_hash');
		$this->loader->add_action('wp_ajax_settings_sync_products', $this, 'get_all_products');
		$this->loader->add_filter( 'woocommerce_product_data_tabs', $plugin_admin, 'powerall_show_tabs' );

		$this->loader->add_action( 'woocommerce_product_data_panels', $plugin_admin, 'powerall_options_product_tab_content' );

		$this->loader->add_action( 'show_user_profile', $plugin_admin, 'powerall_display_user_profile_fields', 20 );
		$this->loader->add_action( 'edit_user_profile', $plugin_admin, 'powerall_display_user_profile_fields', 20 );

		$this->loader->add_action( 'personal_options_update', $plugin_admin,'powerall_save_user_fields' );
		$this->loader->add_action( 'edit_user_profile_update', $plugin_admin, 'powerall_save_user_fields' );
		$this->loader->add_action( 'user_register', $plugin_admin, 'powerall_save_user_fields' );
	// TS 20-01-2021: customers create themselves or Powerall creates them.	$this->loader->add_action( 'woocommerce_created_customer', $this, 'powerall_woocommerce_created_customer', 10, 3);

		$this->loader->add_action( 'admin_init', $plugin_admin, 'register_powerall_settings' );

		$this->loader->add_action('product_cat_add_form_fields', $plugin_admin, 'wh_taxonomy_add_new_meta_field', 10, 1);
		$this->loader->add_action('product_cat_edit_form_fields', $plugin_admin, 'wh_taxonomy_edit_meta_field', 10, 1);
		$this->loader->add_action('edited_product_cat',  $plugin_admin,'wh_save_taxonomy_custom_meta', 10, 1);
		$this->loader->add_action('create_product_cat', $plugin_admin,'wh_save_taxonomy_custom_meta', 10, 1);

        $this->loader->add_action('wp_ajax_test_xhr', $this, 'cron_get_orders');
        $this->loader->add_action( 'woocommerce_api_create_product', $this, 'action_function_name_2099', 10, 2);

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

        if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

        } else {

            return;
        }

		$plugin_public = new Pw_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

		$this->loader->add_action( 'woocommerce_created_customer', $this, 'powerall_woocommerce_created_customer', 10, 3);
		$this->loader->add_action( 'user_register', $plugin_public, 'powerall_save_user_fields', 99 );

		$this->loader->add_action('wp_ajax_nopriv_get_single_product', $this, 'get_one_product');

		$this->loader->add_action('woocommerce_before_shop_loop', $plugin_public, 'get_customer_prices', 10);
	//	$this->loader->add_action('woocommerce_after_shop_loop_item_title', $plugin_public, 'set_price', 10);

     	$this->loader->add_filter('woocommerce_get_price_html', $plugin_public, 'alter_price_display', 9999, 2);

		$this->loader->add_filter('woocommerce_before_single_product', $plugin_public, 'read_prices', 10, 2);

	//	$this->loader->add_filter('woocommerce_add_cart_item_data', $plugin_public, 'add_custom_field_data', 20, 2 );
   // TS 20-01-2021 is geregeld in alter_price_display.     $this->loader->add_action( 'woocommerce_before_add_to_cart_button', $plugin_public, 'custom_product_price_field', 5 );
	//	$this->loader->add_filter('woocommerce_after_cart_item_name', $plugin_public, 'hack_the_table', 10, 2);

		$this->loader->add_filter('woocommerce_before_calculate_totals', $plugin_public, 'before_calculate_totals', 20, 2 );
	    $this->loader->add_action( 'woocommerce_cart_item_price', $plugin_public, 'display_discount_on_cart_price_column', 30, 3 );


		//rem--ove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5 );
	//	$this->loader->add_action( 'woocommerce_payment_complete', $plugin_public, 'powerall_woocommerce_payment_complete', 10, 1 );
	//	$this->loader->add_action( 'woocommerce_order_status_completed' , $plugin_public, 'powerall_woocommerce_payment_complete', 10, 1 );
	//	$this->loader->add_action('woocommerce_order_status_awaiting-delivery', $plugin_public,  'backorder_status_custom_notification', 20, 2);

		$this->loader->add_action('woocommerce_account_content', $plugin_public,  'get_orders_for_account_page', 10, 1);
		$this->loader->add_action( 'woocommerce_before_edit_account_form', $plugin_public,'add_powerall_info_to_edit_account_form' );


		$this->loader->add_filter( 'cron_schedules', $this, 'teowin_cron_schedules');


		$this->loader->add_filter( 'teowin_sync_powerall_products', $this, 'teowin_update_products');
		$this->loader->add_filter( 'teowin_sync_powerall_users', $this, 'teowin_update_customers');
	//	$this->loader->add_filter( 'teowin_sync_powerall_statusses', $this, 'cron_get_orders');
        $this->loader->add_filter( 'teowin_sync_test_cron', $this, 'teowin_function_to_run');

        $this->loader->add_action( 'woocommerce_api_process_product_meta_product_simple', $this, 'action_function_name_2099', 10);
        $this->loader->add_action( 'woocommerce_api_create_product', $this, 'action_function_name_2099', 10, 2);

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {

        if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

        } else {
         //   add_action( 'admin_notices', $this, 'display_admin_notice_about_woocommerce' );    
   
            return;
        }

		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Pw_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

    public function log($msg) {

	    if (is_array($msg)){
	       $_msg = $msg['code'] . ' ' . $msg['message'];

        } else {
	        $_msg = $msg;
        }

        date_default_timezone_set('Europe/Amsterdam');

     //   $result =  '['. date("Y-m-d H:i:s", time()).'] '.$_msg."\n";
        $result =  $_msg."\n";
        $file = plugin_dir_path( dirname( __FILE__ ) )  . '/log.txt';
        //  $plugin_dir    = wp_normalize_path( WP_PLUGIN_DIR );
        file_put_contents($file, $result, FILE_APPEND );
    //    error_log($result, 3, $file);
    }

	public function teowin_cron_schedules($schedules){
		if(!isset($schedules["5min"])){
			$schedules["5min"] = array(
				'interval' => 5*60,
				'display' => __('Elke 5 minuten - Teowin'));
		}
        if(!isset($schedules["10min"])){
            $schedules["10min"] = array(
                'interval' => 10*60,
                'display' => __('Elke 10 minuten - Teowin'));
        }
		if(!isset($schedules["30min"])){
			$schedules["30min"] = array(
				'interval' => 30*60,
				'display' => __('Elk halfuur - Teowin'));
		}
        if(!isset($schedules["iedere_minuut"])){
            $schedules["iedere_minuut"] = array(
                'interval' => 60,
                'display' => __('Iedere minuut - Teowin'));
        }
		return $schedules;
	}

    public function teowin_function_to_run() {

        date_default_timezone_set('Europe/Amsterdam');

        $msg = 'teowin_function_to_run';

        $this->log($msg);
    }

    public function teowin_update_products() {
        $this->log('start cron update products');

        $last_date = get_option( 'POWERALL_LAST_UPDATE');
        $is_sync_on = get_option('powerall_sync');

        if ($is_sync_on) {
            $this->get_all_products($last_date);
            update_site_option(POWERALL_LAST_UPDATE, date("Y-m-d H:i:s", time()));
            $this->log('finish cron update products');
        }
    }

    public function teowin_update_customers(){
        $is_sync_on = get_site_option('powerall_sync');
        if ($is_sync_on) {
            $this->teowin_update_customers();
            $this->log('finish cron update customers');
        }
    }


    public function get_hashed_key(){
	   if ( get_option('powerall_hash') ) {
	   	  return 'Basic ' . get_option('powerall_hash');
	   } else {
	   	  return null;
	   }
    }

    public function action_function_name_2099( $product_id, $data ){
        // action...
        update_post_meta( $product_id, '_productcode', $data['_productcode']);
    }

	public function get_Product_from_API( $productId , $json = false) {

		if ( empty( $productId ) ) {
			$error = array(
				'code'  => '400',
				'message' => 'ProductId is empty'
			);
			$this->log($error);
			return $error;
		}

		$api_key = $this->get_hashed_key();
		$api_url = 'https://webshop.powerall.io/api/v1/products/' . $productId;

		$response = wp_remote_get( $api_url,
			array(
				'timeout' => 30,
				'headers' => array( 'authorization' => $api_key ),
			) );

		if (is_wp_error($response)){
			$error = array('code' => '400',
			               'message' => $response->errors['http_request_failed'][0]
			);
            $this->log($error);
			return $error;
		}

		if ($json == false) {
			$product_data = json_decode( $response['body'], true );
		}
		else {
			$product_data = $response['body'];
		}
		return $product_data;
	}


	public function powerall_place_order($orderitems){
        $api_key = $this->get_hashed_key();
		$api_url = 'https://webshop.powerall.io/api/v1/orders';

        $this->log('powerall_place_order');

		$test = json_encode($orderitems, JSON_PRETTY_PRINT);
		$file = fopen(__DIR__ . '/order.txt','w');
		fwrite($file, $test);
		fclose($file);

		$response = wp_remote_post( $api_url ,
			array(
				'timeout' => 30,
				'headers' => array( 'authorization' => $api_key ,
				                    'Content-Type' => 'application/json; charset=utf-8'),
				'body'      => $test,

			 ));


		if (is_wp_error($response)){
			$error = array('code' => '400',
			               'error' => $response->errors['http_request_failed'][0]
			);
            $this->log($error);
			return $error;
		}

		if ($response['response']['code'] == 201){
			$ordernumber = json_decode( $response['body'], true );

			/* OK we ordered ourselves a game! */
			/* Next: dispatch the same */
			/* then get serials */
			$order_data   = array('code'        => '200',
			                      'ordernumber' => $ordernumber['orderId'],
                                 );
			return $order_data;

		}
		else {
			$error = array('code' => '400',
			               'error' => $response['body'] ,
			);
            $this->log($error);
			return $error;
		}

	}


    public function powerall_create_customer($customer){
        $api_key = $this->get_hashed_key();
        $api_url = 'https://webshop.powerall.io/api/v1/customers';

        $this->log('powerall_create_customer');

        $test = json_encode($customer, JSON_PRETTY_PRINT);
        $file = fopen(__DIR__ . '/customer.txt','w');
        fwrite($file, $test);
        fclose($file);

        $response = wp_remote_post( $api_url ,
            array(
                'timeout' => 30,
                'headers' => array( 'authorization' => $api_key ,
                'Content-Type' => 'application/json; charset=utf-8'),
                'body'      => $test,

            ));

        if ($response['response']['code'] == 201) {
            $error = array('code' => '201',
                'message' => 'Created');
        } else {

            $error = array('code' => '400',
                'message' => 'Exists but is not activated');

        }


       $this->log($error);

        return $error;
    }



	/**
	 * Call the Powerall API, get product data and fill the current
	 * product object. Ajax call, executed from the blue button in the
	 * product edit form.
	 **/
	public function get_one_product(){

		$postId      = $_POST['postid'];
		$productId   = $_POST['productcode'];

		global $post;

		if ( ! isset( $postId ) ) {
			echo "postid missing";
		}

		$product_data = $this->get_Product_from_API($productId);

        if ($product_data) {

			if (sizeof($product_data['SalesPrice']) == 2)
			{
				$product_data['SalesPrice'] = floatval($product_data['SalesPrice'] . '.00');
			}

			if (isset($post)) {
				$post->post_title = $product_data['Description'];
			}

			$the_product = wc_get_product( $postId );

			$the_product->set_virtual(false);
			$the_product->set_downloadable(false);
			$the_product->set_sku($product_data['ProductCode']);
			$the_product->set_regular_price(floatval(number_format ( $product_data['SalesPrice'] , 2 ,  "." ,  "," )) );
			$the_product->set_name($product_data['Description']);
			$the_product->set_description($product_data['Description']);
			$the_product->set_status('Draft');
			$the_product->set_price(floatval(number_format ( $product_data['SalesPrice'] , 2 ,  "." ,  "," )) );
			$the_product->set_sale_price(floatval(number_format ( $product_data['SalesPrice'] , 2 ,  "." ,  "," )) );

		   $theID =	$the_product->save();

			$the_product->update_meta_data( '_EANCode', sanitize_text_field( $product_data['EanCode'] ) );

		//	$the_product->save_meta_data();

			wp_send_json_success( __('Product Updated', twpw), '200');
			wp_die();
		}

	}

	public function get_all_customers_from_API() {
        $this->log('BEGIN - get_all_customers_from_API');
		$api_key = $this->get_hashed_key();
		$api_url = 'https://webshop.powerall.io/api/v1/customers/all';

		$response = wp_remote_get( $api_url,
			array(
				'timeout' => 90,
				'headers' => array( 'authorization' => $api_key ),
			) );

		if (is_wp_error($response)){
			$error = array('code' => '400',
			               'message' => $response->errors['http_request_failed'][0]
			);
            $this->log($error);
			return $error;
		}

		$customer_list = json_decode( $response['body'], true );

		foreach($customer_list as $customer) {

			/* STRIP_comment
				Haal de klantenlijst uit PowerallAPI en maak klanten bij of update bestaande klanten.
			    cust_1
			*/

            $this->create_or_update_wc_customer($customer);
		}

		wp_send_json_success( __('Alle klanten geupdate', twpw), '200');
		wp_die();
        $this->log('END - get_all_customers_from_API');
	}

	public function get_Customer_by_ID( $productId , $json = false) {

		if ( empty( $productId ) ) {
			$error = array(
				'code'  => '400',
				'message' => 'ProductId is empty'
			);
			return $error;
		}

		$api_key = $this->get_hashed_key();
		$api_url = 'https://webshop.powerall.io/api/v1/products/' . $productId;

		$response = wp_remote_get( $api_url,
			array(
				'timeout' => 30,
				'headers' => array( 'authorization' => $api_key ),
			) );

		if (is_wp_error($response)){
			$error = array('code' => '400',
			               'message' => $response->errors['http_request_failed'][0]
			);
			return $error;
		}

		if ($json == false) {
			$product_data = json_decode( $response['body'], true );
		}
		else {
			$product_data = $response['body'];
		}
		return $product_data;
	}

    public function create_or_update_wc_customer($customer){
        $this->log('BEGIN - create_or_update_customer');

	    $user = get_user_by('login', $customer['Id']);

		 /* STRIP_comment
			Haal de klantenlijst uit PowerallAPI en maak klanten bij of update bestaande klanten.
			cust_2
		*/
	    if (!$user && $customer['EmailAddress']){

		    $default_password = wp_generate_password();
		    $user = wp_create_user($customer['Id'], $default_password, $customer['EmailAddress']);
            wp_update_user( array( 'ID' => $user->ID, 'role' => 'customer' ) );
	    }

	    if ($user) {
            update_user_meta( $user->ID, "IsActive", $customer['IsActive']);
		    update_user_meta( $user->ID, "billing_company", $customer['Name'] );
		    update_user_meta( $user->ID, "billing_address_1", $customer['Address'] );
		    update_user_meta( $user->ID, "billing_postcode", $customer['ZipCode'] );
		    update_user_meta( $user->ID, "billing_city", $customer['Town'] );
		    update_user_meta( $user->ID, "billing_country", $customer['CountryCode'] );
		    update_user_meta( $user->ID, "billing_phone", $customer['Phone'] );
		    update_user_meta( $user->ID, "powerall_id", $customer['Id'] );
		    update_user_meta( $user->ID, "isactive", $customer['IsActive'] );
		    update_user_meta( $user->ID, "powerall_relationcode", $customer['RelationCode'] );
		    update_user_meta( $user->ID, "customercontact", $customer['ContactPerson'] );
		    update_user_meta( $user->ID, "discount_group", $customer['DiscountGroup'] );
		    update_user_meta( $user->ID, "paycondition", $customer['PayCondition'] );
		    update_user_meta( $user->ID, "acceptorders", $customer['AcceptOrders'] );
		    update_user_meta( $user->ID, "isbusiness", $customer['IsBusiness'] );

		    /* STRIP_comment
				Haal de verzendadressen uit PowerAll
				cust_3
			*/


		    $shipment_data = $this->get_customer_adresses( $customer['Id'] );

		    if ( $shipment_data ) {
			    foreach ( $shipment_data as $address ) {

			    }
		    }


		 //   $user->save();
		//    return;
	    }
	    $this->log('EIND - create_or_update_customer');
    }

	public function get_customer_adresses( $customerId) {

		if ( empty( $customerId ) ) {
			$error = array(
				'code'  => '400',
				'message' => 'customerId is empty'
			);
			return $error;
		}

		$api_key = $this->get_hashed_key();
		$api_url = 'https://webshop.powerall.io/api/v1/customers/' . $customerId . '/delivery-addresses';

		$response = wp_remote_get( $api_url,
			array(
				'timeout' => 30,
				'headers' => array( 'authorization' => $api_key ),
			) );

		if (($response['response']['code'] > 200) | ($response['body'] == '') ) {
			return null;
		}


		$product_data = json_decode( $response['body'], true );

		return $product_data;
	}


	public function get_wc_customer_data($customerID) {
		$customer = [];

		$customer['Name']          = get_user_meta( $customerID, "billing_company", true );
		$customer['Address']       = get_user_meta( $customerID, "billing_address_1", true );
		$customer['ZipCode']       = get_user_meta( $customerID, "billing_postcode", true );
		$customer['Town']          = get_user_meta( $customerID, "billing_city", true );
		$customer['CountryCode']   = "nl"; // = get_user_meta( $customerID , "billing_country", , true );
		$customer['Phone']         = get_user_meta( $customerID, "billing_phone", true );
		$customer['Id']            = get_user_meta( $customerID, "beverid", true );
		$customer['IsActive']      = get_user_meta( $customerID, "isactive", true );
		$customer['RelationCode']  = get_user_meta( $customerID, "customercode", true );
		$customer['ContactPerson'] = get_user_meta( $customerID, "customercontact", true );
		$customer['DiscountGroup'] = get_user_meta( $customerID, "ciscountgroup", true );
		$customer['PayCondition']  = get_user_meta( $customerID, "paycondition", true );
		$customer['AcceptOrders']  = get_user_meta( $customerID, "acceptorders", true );
		$customer['IsBusiness']    = get_user_meta( $customerID, "isbusiness", true );

		return $customer;
	}

	public function powerall_woocommerce_created_customer( $customer_id, $new_customer_data, $password_generated ) {
		// make action magic happen here...

	   $klant =	$this->get_wc_customer_data($customer_id);
	   $powerallklant = get_user_meta($customer_id, 'powerall_id', true);

	   if (!powerallklant){
	   	 update_user_meta($customer_id, 'paycondition', 1); // Nieuwe klant, betaling via een gateway.
	   }


	}

	public function update_customer(){
		//
	}

	public function generate_API_hash()
	{
	//	if ($_POST['my_plugin_ajax_submit']) {

			$name = $_POST['name'];
			$key = $_POST['key'];
            try {
	            $hash = sprintf( '%s', base64_encode( sprintf( '%s:%s', $name, $key ) ) );
	            wp_send_json_success(array('hash' => $hash,
	                                       'nonce' => $_POST['nonce']), 200);

            } catch (\Exception $ex) {

	            wp_send_json_error( $ex->getMessage(), '401' );
            }


	//	} else {
	//		wp_send_json_error( 'nonce not found', '401' );
	//	}
		wp_die();
	}

	public function get_categories(){
     //   https://webshop.powerall.io/api/v1/productgroups
	}

	public function get_all_products($lastDate=null){

        $this->log('BEGIN - get_all_products');
		$api_key = $this->get_hashed_key();
        $dir = plugin_dir_path( __FILE__ );

        $stop_sync = false;

		if (file_exists($dir . '/all_products.txt'))
        {
            $this->log('Synchronisatie bezig');
            return;
        }

		$date = null;

        if ($lastDate) {
            $date = DateTime::createFromFormat("Y-m-d H:i:s", $lastDate);
        } else {
            $file = fopen($dir . '/all_products.txt','w');
            fwrite($file, 'Get_all_products');
            fclose($file);
        }

		// either get all products in the shop or the ones changed since the last sync.
		if ($date) {
            $api_url = 'https://webshop.powerall.io/api/v1/products/changes/' . $lastDate;
        } else {
            $api_url = 'https://webshop.powerall.io/api/v1/products/all';
        }

		$response = wp_remote_get( $api_url,
			array(
				'timeout' => 240,
				'headers' => array( 'authorization' => $api_key ),
			) );

		if (($response['response']['code'] > 200) | ($response['body'] == '') || (isset($response['errors']))) {

            $this->log('error get all products -> ' . $response['response']['code']);
            $this->log($api_url);
			return null;
		}

        $file = fopen($dir . '/all_products.json','w');
        fwrite($file, $response['body']);
        fclose($file);

		$product_data = json_decode( $response['body'], true );

		$this->log('Aantal producten: ' . count($product_data));

		$counter = 1;
        $this->log('BEGIN - product_data');

        $gebruikwebshoptekst = get_option('gebruikwebshoptekst');

		if ($product_data) {
       //     $this->log('product_data');
			foreach ( $product_data as $product ) {

			    if ($gebruikwebshoptekst) {
			        $producttekst = $product['WebshopText'];
                } else {
			        $producttekst = $product['Description'];
                }

                 $counter ++;
                 set_time_limit(60); //timelimit per loop iteration
                 try {
                     // try to find the product
                     if (!$product['ProductCode'] || !$producttekst || !$product['Description'] )
                     {
                         if (isset($product['ProductCode'])) {
                             $this->log('Ongeldig product -> omschrijving leeg: ' . $product['ProductCode'] );
                         } else {
                             $this->log('Ongeldig product');
                         }
                             continue;
                     }


                     $args = array(
                         'post_type' => 'product',
                         'meta_key' => '_productcode',
                         'meta_value' => $product['ProductCode'], //'meta_value' => array('yes'),
                         'meta_compare' => '=' //'meta_compare' => 'NOT IN'
                     );

                     $products = wc_get_products($args);

                     $the_product = null;

                     if (count($products) > 0) {
                         $the_product = wc_get_product($products[0]->id);
                         $post_id = $the_product->get_id();
                         $this->log('= '. $post_id . ' ' . $product['ProductCode'] . ' ' . $producttekst . ' ' . number_format($product['SalesPrice'], 2, wc_get_price_decimal_separator(), wc_get_price_thousand_separator()));
                     }

                     if (!$the_product) {
                         $post_id = wp_insert_post(
                             array(
                                 'post_title' => $product['Description'],
                                 'post_type' => 'product',
                                 'post_status' => 'publish'
                             )
                         );
                         // If the description is empty, fill it with the description from Powerall.
                         $the_product = wc_get_product($post_id);

                         $the_product->set_description($producttekst);

                         $the_product->set_short_description($product['Description']);
                         $this->log('+ ' . $post_id . ' ' . $product['ProductCode'] . ' '  . $producttekst . ' ' . number_format($product['SalesPrice'], 2, wc_get_price_decimal_separator(), wc_get_price_thousand_separator()));

                     } else {
                         if (get_option('gebruikwebshoptekst') == true){
                             $the_product->set_description($producttekst);
                             $the_product->set_short_description($product['Description']);
                         } else { // Alleen als ie leeg is

                             if ($the_product->get_description() == '') {
                                 $the_product->set_description($producttekst);
                             }
                             if ($the_product->get_short_description() == '') {
                                 $the_product->set_short_description($product['Description']);
                             }
                         }
                     }

                     // Bever heeft aangegeven dat ProductGroups uit de api niet ondersteund worden
                     // en niet geschikt zijn om producten te categoriseren. Als optie mag de klant het zelf bepalen.
                     $handleProductGroups = get_option('gebruikproductgroepen');
                     if ($handleProductGroups) {
                         $productgroups = array();

                         // Test of hoofdgroep bestaat en zo niet voeg het toe.
                         $mainterm_id = term_exists($product['MainGroup']);

                         if ($mainterm_id == null) {

                             $mainterm_id = wp_insert_term(
                                 $product['MainGroup'], // the term
                                 'product_cat', // the taxonomy
                                 array(
                                     'description' => $product['MainGroupDescription'],
                                     'slug' => $product['MainGroup'],
                                     'parent' => -1
                                 ));

                             update_post_meta($post_id, 'product_cat', $mainterm_id);

                         } else {
                             update_post_meta($post_id, 'product_cat', $mainterm_id);
                             /*      <?php update_post_meta(76, 'my_key', 'Steve'); ?> */
                         }


                         $productgroups[] = $mainterm_id;

                         // Test of subgroep bestaat en zo niet voeg de subgroep toe.
                         $subterm_id = term_exists($product['SubGroup']);

                         if ($subterm_id == null) {

                             $subterm_id = wp_insert_term(
                                 $product['SubGroup'], // the term
                                 'product_cat', // the taxonomy
                                 array(
                                     'description' => $product['SubGroupDescription'],
                                     'slug' => $product['subgroep'],
                                     'parent' => $mainterm_id
                                 ));

                             update_post_meta($post_id, 'subcategorie', $subterm_id);

                         } else {
                             update_post_meta($post_id, 'subcategorie', $subterm_id);
                         }


                         $productgroups[] = $subterm_id;

                         // Test of subgroep bestaat en zo niet voeg de subgroep toe.
                         $subsubterm_id = term_exists($product['SubSubGroup']);

                         if ($subsubterm_id == null) {

                             $subsubterm_id = wp_insert_term(
                                 $product['SubSubGroup'], // the term
                                 'product_cat', // the taxonomy
                                 array(
                                     'description' => $product['SubDunGroupDescription'],
                                     'slug' => $product['subsubgroep'],
                                     'parent' => $mainterm_id
                                 ));

                             update_post_meta($post_id, 'subsubcategorie', $subterm_id);

                         } else {
                             update_post_meta($post_id, 'subsubcategorie', $subterm_id);
                         }

                         $productgroups[] = $subsubterm_id;

                         $the_product->set_category_ids($productgroups);

                     };

                     // Then we use the product ID to set all the posts meta
                     wp_set_object_terms($post_id, 'pw_product', 'product_type'); // set product is simple/variable/grouped
                     update_post_meta($post_id, '_invoicetext', $product['Description']); // invoicetext.
                     update_post_meta($post_id, '_visibility', 'visible');
                     update_post_meta($post_id, '_stock_status', 'instock');
                     update_post_meta($post_id, 'total_sales', '0');
                     update_post_meta($post_id, '_downloadable', 'no');
                     update_post_meta($post_id, '_virtual', 'no');
                     update_post_meta($post_id, '_regular_price', number_format($product['SalesPrice'], 2, ",", "."));
                     update_post_meta($post_id, '_sale_price', '');
                     update_post_meta($post_id, '_purchase_note', '');
                     update_post_meta($post_id, '_featured', 'no');
                     update_post_meta($post_id, '_weight', '0');
                     update_post_meta($post_id, '_length', '0');
                     update_post_meta($post_id, '_width', '0');
                     update_post_meta($post_id, '_height', '0');
                     update_post_meta($post_id, '_sku', $product['ProductCode']);
                     update_post_meta($post_id, '_product_attributes', array());
                     update_post_meta($post_id, '_sale_price_dates_from', '');
                     update_post_meta($post_id, '_sale_price_dates_to', '');
                     update_post_meta($post_id, '_price', number_format($product['SalesPrice'], 2, ",", "."));
                     update_post_meta($post_id, '_sold_individually', '');
                     update_post_meta($post_id, '_manage_stock', 'no'); // activate stock management
                     //		wc_update_product_stock( $post_id, 1000, 'set' ); // set 1000 in stock
                     update_post_meta($post_id, '_backorders', 'no');
                     update_post_meta($post_id, '_productcode', sanitize_text_field($product['ProductCode']));

                     if ($product['ImageUrls']) {
                         foreach ($product['ImageUrls'] as $prodimage_url) // example image
                         {


                             // magic sideload image returns an HTML image, not an ID
                             $media = media_sideload_image($prodimage_url, $post_id);

                             // therefore we must find it so we can set it as featured ID
                             if (!empty($media) && !is_wp_error($media)) {
                                 $args = array(
                                     'post_type' => 'attachment',
                                     'posts_per_page' => -1,
                                     'post_status' => 'any',
                                     'post_parent' => $post_id
                                 );

                                 // reference new image to set as featured
                                 $attachments = get_posts($args);

                                 if (isset($attachments) && is_array($attachments)) {
                                     foreach ($attachments as $attachment) {
                                         // grab source of full size images (so no 300x150 nonsense in path)
                                         $image = wp_get_attachment_image_src($attachment->ID, 'full');
                                         // determine if in the $media image we created, the string of the URL exists
                                         if (strpos($media, $image[0]) !== false) {
                                             // if so, we found our image. set it as thumbnail
                                             set_post_thumbnail($post_id, $attachment->ID);
                                             // only want one image
                                             break;
                                         }
                                     }
                                 }
                             }
                         }
                     }

                     $the_product->save();

                     //       $counter ++;
                     //       if ( $counter === 5 ) {
                     //           break;
                     //      }

                 }  catch (Exception $e) {
                     $this->log('Caught exception: ',  $e->getMessage());
                     continue;
                 }

			 }
            $this->log('EIND - get_all_products');

			wp_delete_file($dir . '/all_products.txt');
			return( __('Products Updated maar vergeet niet om het tellertje weg te halen', twpw));
			wp_die();
		}


	}


	public function powerall_get_customer_prices($userid, $productcodes){
		$api_key = $this->get_hashed_key();
		$api_url = 'https://webshop.powerall.io/api/v1/prices?customerId=';

		$api_url = $api_url . $userid . '&productCodes=' . $productcodes;

		$response = wp_remote_get( $api_url ,
			array(
				'timeout' => 30,
				'headers' => array( 'authorization' => $api_key ,
				                    'Content-Type' => 'application/json; charset=utf-8'),


			));




		if (is_wp_error($response)){
			return null;
		}

		if ($response['response']['code'] == 200){
			$pricedata = json_decode( $response['body'], true );

            return($pricedata);
		}
		else {
			return null;
		}

	}

	public function update_price_agreements(){
		$api_key = $this->get_hashed_key();
		$api_url = 'https://webshop.powerall.io/api/v1/price-agreements/all';

		$response = wp_remote_get( $api_url,
			array(
				'timeout' => 30,
				'headers' => array( 'authorization' => $api_key ),
			) );

		if (($response['response']['code'] > 200) | ($response['body'] == '') ) {
			return null;
		}

		$price_data = json_decode( $response['body'], true );
 		

		if ($price_data) {
			foreach ( $price_data as $agreement ) {


			}



			wp_send_json_success( __('Products Updated maar vergeet niet om het tellertje weg te halen', twpw), '200');
			wp_die();
		}


	}


	public function powerall_get_customer_orders($userid){
        $api_key = $this->get_hashed_key();
        $api_url = 'https://webshop.powerall.io/api/v1/orders?customerId=';

        $api_url = $api_url . $userid;

        $response = wp_remote_get( $api_url ,
            array(
                'timeout' => 30,
                'headers' => array( 'authorization' => $api_key ,
                                    'Content-Type' => 'application/json; charset=utf-8'),


            ));


        if (is_wp_error($response)){
            $error = array('code' => '400',
                           'error' => $response->errors['http_request_failed'][0]
            );
            return null;
        }

        if ($response['response']['code'] == 200){
            $orderdata = json_decode( $response['body'], true );

            return($orderdata);
        }
        else {
            return null;
        }

    }

    public function cron_get_orders()
    {

        $args = array(
            'role' => 'customer',
            'number' => -1,
            'order' => 'ASC',

        );

        $query = new WP_User_Query($args);
        $klanten = $query->get_results();

        if (!empty($klanten)){
            foreach($klanten as $klant){

                $klantnummer = null;

                $klantnummer = get_user_meta($klant->ID, 'powerall_id', true);

                if ($klantnummer) {
                    $customer = new WC_Customer(get_current_user_id());
                    $billing_adress = $customer->get_billing('view');
                    $shipment_address = $customer->get_shipping('view');

                    $dropship = PwDropShipment::get_instance();
                    $pworders = $dropship->powerall_get_customer_orders($klantnummer);

                    if ($pworders && $pworders['TotalItems'] > 0) {


                        foreach ($pworders['Items'] as $pworder) {

                            $wooOrder = wc_get_orders(array(
                                'limit' => 1,
                                'orderby' => 'date',
                                'order' => 'DESC',
                                'meta_key' => '_powerallOrderID',
                                'meta_compare' => 'EQUALS',
                                'meta_value' => $pworder['Id']
                            ));

                            $pwFout = 0;

                            if (!$wooOrder) {
                                $args = array(
                                    'customer_id' => get_current_user_id(),
                                    'created_via' => 'PowerAll Offline',
                                );

                                // Get an instance of the current WC_DateTime object
                                $date_time = new WC_DateTime();
                                $date_time->createFromFormat('Y-m-d H:i:s', $pworder['OrderDate']);

                                $wooOrder = wc_create_order($args);
                                $wooOrder->set_address($billing_adress, 'billing');
                                $wooOrder->set_address($shipment_address, 'shipping');
                                $wooOrder->set_date_created($date_time);
                                $wooOrder->set_prices_include_tax('yes' === get_option('woocommerce_prices_include_tax'));

                                $products = $pworder['Lines'];

                                foreach ($products as $pwProduct) {
                                    $wooProduct = wc_get_product(wc_get_product_id_by_sku($pwProduct['ProductCode']));
                                    if ($wooProduct) {
                                        $wooOrder->add_product($wooProduct, $pwProduct['Quantity'], array('total' => $pwProduct['NetPrice']));
                                    } else {
                                        $pwFout = 1;
                                    }
                                }

                                $wooOrder->calculate_totals(true);
                                $wooOrder->update_meta_data('_powerallOrderID', $pworder['Id']);
                                // $wooOrder->update_status('Afgerond', 'PowerAll Winkelorder');
                                $wooOrder->update_status('completed');
                                $wooOrder->save();
                            }
                        }
                    }
                }

            }
        }
    }

    public function test_xhr()
    {

       for ( $i = 0; $i < 50; $i++) {
          // return( 'stap ' . $i );
           wp_send_json($i);
           ob_flush();
           flush();
           sleep(2);

       }
    }




}
